# pytoxr
Open-source ToxR data analysis.

Transmembrane-domain interactions of proteins are vital for cellular function. ToxR, TOXCAT and dsTBL are powerful tools for investigating these interactions in natural membrane environment. The pytoxr module contains tools for the analysis of data from ToxR-based laboratory experiments.

#Requirements
Current requirements include the eccpy package (https://github.com/teese/eccpy).

